<?php
/*
 $Id: usercal-modify.php,v 1.2 2003/11/20 23:02:52 adeniz Exp $

 Copyright (C) 2003 Baker Research, Ltd.

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*
  This script modifies an existing record in the termine table in the
  PHProjekt database for a given user.

  See protocols.dvi for a description of this script.

*/

// Include the common library.
require('sync_common.php');

// If debugging is enabled, put up a web page with the variable info.
if (isset($debugVars)) {
  echo debug_header("$PHP_SELF");
  debug($userName, "userName");
  debug($userPW, "userPW");
  debug($recID, "recID");
  debug($recDesc, "recDesc");
  debug($recNote, "recNote");
  debug($recDate, "recDate");
  debug($recBegin, "recBegin");
  debug($recEnd, "recEnd");
  debug($ldap, "ldap");
  debug($pw_crypt, "pw_crypt");
}

// Check that all required variables are present.
if (!isset($userName) || (!isset($userPW)) || (!isset($recID))) {
  error_exit("$programError:  Missing input", $debugVars);
}

// Get the PHProjekt user ID, checking for unique userName and correct userPW.
$dbID = check_user_pw($userName, $userPW, $debugVars);

// Create SQL query to check that the record with the specified ID and
// user exists.
$query = "SELECT id, von FROM termine WHERE (an = $dbID) AND (id = $recID)";
if (isset($debugVars))
  debug($query, "Record check");
$result = db_query($query) or error_exit("$databaseError:  Query:  '$query'",
					 $debugVars);

$nRows = 0;
while ($row = db_fetch_row($result)) {
  $creator = $row[1];
  $nRows++;
}

// Check for unique record.
if ($nRows != 1)
  error_exit("$dataError:  No unique record for user '$userName' ".
	     "and record ID '$recID'", $debugVars);

// Check that this user created this record, and can therefore modify it.
if ($creator <> $dbID)
  error_exit("$dataError:  Attempt to modify a read-only record", $debugVars);

// Assemble the SQL query to modify this record.
$query = "UPDATE termine SET an = $dbID";
if (isset($recDesc))
  $query = $query.", event = '$recDesc'";
if (isset($recNote))
  $query = $query.", note = '$recNote'";
if (isset($recDate)) {
  // Check the format of the date.
  $recDates = check_date_format_exit($recDate, $debugVars);
  $dbDate = db_format_date($recDates);
  $query = $query.", datum = '$dbDate'";
}
if (isset($recBegin)) {
  // Check the format of the times.
  $recBegins = check_time_format_exit($recBegin, $debugVars);
  $dbBegin = db_format_time($recBegins);
  $query = $query.", anfang = '$dbBegin'";
}
if (isset($recEnd)) {
  // Check the format of the times.
  $recEnds = check_time_format_exit($recEnd, $debugVars);
  $dbEnd = db_format_time($recEnds);
  $query = $query.", ende = '$dbEnd'";
}
$query = $query." WHERE (an = $dbID) AND (id = $recID)";
if (isset($debugVars))
  debug($query, "Record update");

// Execute the query.
$result = db_query($query) or error_exit("$databaseError:  Query:  '$query'",
					 $debugVars);

// Send the success status.
echo "$success";

// If debugging is enabled, show the ID and send the footer.
if (isset($debugVars))
  echo debug_footer();
?>
